@@ -10,6 +10,7 @@ from orglearn.anki.anki_convertor import AnkiConvertor
 from orglearn.anki.node_convertor import AnkiConvertMode
 from orglearn.mind_map.backend.backends import Backends
 from orglearn.mind_map.map_convertor import MapConvertor
+from orglearn.preprocessor import preprocess_string
 
 
 @click.group(invoke_without_command=True)
@@ -186,7 +187,7 @@ def pdf(org_files: typing.Tuple[str], heading_level: int) -> None:
                 input_content += "#+OPTIONS: H:{}\n".format(heading_level)
 
             with open(file_path, "r") as input_file:
-                input_content += input_file.read()
+                input_content += preprocess_string(input_file.read())
 
             # Change the compilation context to the file directory
             # this is needed in order to include images from the paths relative to org file
